Class: SemanticLogger::Base
- Inherits:
-
Object
- Object
- SemanticLogger::Base
- Defined in:
- lib/semantic_logger/base.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#filter ⇒ Object
Class name to be logged.
-
#instance_named_tags ⇒ Object
readonly
Tags permanently bound to this logger instance via
#tagged(without a block). -
#instance_tags ⇒ Object
readonly
Tags permanently bound to this logger instance via
#tagged(without a block). -
#name ⇒ Object
Class name to be logged.
Instance Method Summary collapse
-
#backtrace(thread: Thread.current, level: :warn, message: "Backtrace:", payload: nil, metric: nil, metric_amount: nil) ⇒ Object
Log a thread backtrace.
-
#fast_tag(tag) ⇒ Object
:nodoc:.
-
#level ⇒ Object
Returns the current log level if set, otherwise it returns the global default log level.
-
#level=(level) ⇒ Object
Set the logging level for this logger.
-
#log(_log_) ⇒ Object
Write log data to underlying data storage.
-
#measure(level, message, params = {}, &block) ⇒ Object
(also: #benchmark)
Dynamically supply the log level with every measurement call.
- #named_tags ⇒ Object
-
#pop_tags(quantity = 1) ⇒ Object
:nodoc:.
-
#push_tags(*tags) ⇒ Object
Returns the list of tags pushed after flattening them out and removing blanks.
-
#should_log?(log) ⇒ Boolean
Whether this log entry meets the criteria to be logged by this appender.
-
#silence(new_level = :error) ⇒ Object
:nodoc:.
-
#tagged(*tags) ⇒ Object
(also: #with_tags)
Add the tags or named tags to the list of tags to log for this thread whilst the supplied block is active.
-
#tags ⇒ Object
:nodoc:.
-
#with_level(new_level) ⇒ Object
Set the logging level for this logger during the execution of the given block.
Instance Attribute Details
#filter ⇒ Object
Class name to be logged
10 11 12 |
# File 'lib/semantic_logger/base.rb', line 10 def filter @filter end |
#instance_named_tags ⇒ Object
Tags permanently bound to this logger instance via #tagged (without a block).
Empty for a regular (non-child) logger.
240 241 242 |
# File 'lib/semantic_logger/base.rb', line 240 def @instance_named_tags end |
#instance_tags ⇒ Object
Tags permanently bound to this logger instance via #tagged (without a block).
Empty for a regular (non-child) logger.
240 241 242 |
# File 'lib/semantic_logger/base.rb', line 240 def @instance_tags end |
#name ⇒ Object
Class name to be logged
10 11 12 |
# File 'lib/semantic_logger/base.rb', line 10 def name @name end |
Instance Method Details
#backtrace(thread: Thread.current, level: :warn, message: "Backtrace:", payload: nil, metric: nil, metric_amount: nil) ⇒ Object
Log a thread backtrace
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/semantic_logger/base.rb', line 140 def backtrace(thread: Thread.current, level: :warn, message: "Backtrace:", payload: nil, metric: nil, metric_amount: nil) log = Log.new(name, level) return false unless meets_log_level?(log) backtrace = if thread == Thread.current Utils.extract_backtrace(caller) else log.thread_name = thread.name log. = (thread[:semantic_logger_tags] || []).clone log. = (thread[:semantic_logger_named_tags] || {}).clone thread.backtrace end if backtrace += "\n" << backtrace.join("\n") end if log.assign(message: , backtrace: backtrace, payload: payload, metric: metric, metric_amount: metric_amount) && !filtered?(log) self.log(log) else false end end |
#fast_tag(tag) ⇒ Object
:nodoc:
265 266 267 |
# File 'lib/semantic_logger/base.rb', line 265 def fast_tag(tag, &) SemanticLogger.fast_tag(tag, &) end |
#level ⇒ Object
Returns the current log level if set, otherwise it returns the global default log level
33 34 35 |
# File 'lib/semantic_logger/base.rb', line 33 def level @level || SemanticLogger.default_level end |
#level=(level) ⇒ Object
Set the logging level for this logger
Note: This level is only for this particular instance. It does not override the log level in any logging instance or the default log level SemanticLogger.default_level
Must be one of the values in SemanticLogger::LEVELS, or nil if this logger instance should use the global default level
20 21 22 23 24 25 26 27 28 29 |
# File 'lib/semantic_logger/base.rb', line 20 def level=(level) if level.nil? # Use the global default level for this logger @level_index = nil @level = nil else @level_index = Levels.index(level) @level = Levels.level(@level_index) end end |
#log(_log_) ⇒ Object
Write log data to underlying data storage
270 271 272 |
# File 'lib/semantic_logger/base.rb', line 270 def log(_log_) raise NotImplementedError, "Logging Appender must implement #log(log)" end |
#measure(level, message, params = {}, &block) ⇒ Object Also known as: benchmark
Dynamically supply the log level with every measurement call
127 128 129 130 131 132 133 134 |
# File 'lib/semantic_logger/base.rb', line 127 def measure(level, , params = {}, &block) index = Levels.index(level) if level_index <= index measure_internal(level, index, , params, &block) elsif block yield(params) end end |
#named_tags ⇒ Object
234 235 236 |
# File 'lib/semantic_logger/base.rb', line 234 def SemanticLogger. end |
#pop_tags(quantity = 1) ⇒ Object
:nodoc:
255 256 257 |
# File 'lib/semantic_logger/base.rb', line 255 def (quantity = 1) SemanticLogger.(quantity) end |
#push_tags(*tags) ⇒ Object
Returns the list of tags pushed after flattening them out and removing blanks
Note:
- This method is slow since it needs to flatten the tags and remove empty elements to support Rails 4.
- For better performance with clean tags, use
SemanticLogger.push_tags
248 249 250 251 252 |
# File 'lib/semantic_logger/base.rb', line 248 def (*) # Need to flatten and reject empties to support calls from Rails 4 = .flatten.collect(&:to_s).reject(&:empty?) SemanticLogger.(*) end |
#should_log?(log) ⇒ Boolean
Whether this log entry meets the criteria to be logged by this appender.
275 276 277 |
# File 'lib/semantic_logger/base.rb', line 275 def should_log?(log) meets_log_level?(log) && !filtered?(log) end |
#silence(new_level = :error) ⇒ Object
:nodoc:
260 261 262 |
# File 'lib/semantic_logger/base.rb', line 260 def silence(new_level = :error, &) SemanticLogger.silence(new_level, &) end |
#tagged(*tags) ⇒ Object Also known as:
Add the tags or named tags to the list of tags to log for this thread whilst the supplied block is active.
Returns result of block.
Tagged example:
SemanticLogger.tagged(12345, 'jack') do
logger.debug('Hello World')
end
Named Tags (Hash) example:
SemanticLogger.tagged(tracking_number: 12345) do
logger.debug('Hello World')
end
Notes:
-
Named tags are the recommended approach since the tag consists of a name value pair this is more useful than just a string value in the logs, or centralized logging system.
-
This method is slow when using multiple text tags since it needs to flatten the tags and remove empty elements to support Rails 4.
-
It is recommended to keep tags as a list without any empty values, or contain any child arrays. However, this api will convert:
`logger.tagged([['first', nil], nil, ['more'], 'other'])`to:
`logger.tagged('first', 'more', 'other')` -
For better performance with clean tags, see
SemanticLogger.tagged.
Child logger:
- When called without a block, returns a new logger instance that permanently
carries the supplied tags ("instance tags"). Those tags are added to every log
entry emitted by the returned logger, and only that logger, even across threads.
Unlike the block form they are not pushed onto the thread, so other loggers are
unaffected. This is the recommended way to bind a logger to an object's identity:
logger = SemanticLogger['Cart'].tagged(cart_id: cart.id)
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/semantic_logger/base.rb', line 207 def tagged(*) # No block: build a child logger that carries these tags on every entry. return tagged_child() unless block_given? block = -> { yield(self) } # Allow named tags to be passed into the logger # Rails::Rack::Logger passes logs as an array with a single argument if .size == 1 && !.first.is_a?(Array) tag = [0] return yield if tag.nil? || tag == "" return tag.is_a?(Hash) ? SemanticLogger.named_tagged(tag, &block) : SemanticLogger.fast_tag(tag.to_s, &block) end # Need to flatten and reject empties to support calls from Rails 4 = .flatten.collect(&:to_s).reject(&:empty?) SemanticLogger.tagged(*, &block) end |
#tags ⇒ Object
:nodoc:
230 231 232 |
# File 'lib/semantic_logger/base.rb', line 230 def SemanticLogger. end |
#with_level(new_level) ⇒ Object
Set the logging level for this logger during the execution of the given block
Refer to the documentation for #level= for more information about the possible log levels.
40 41 42 43 44 45 46 47 48 |
# File 'lib/semantic_logger/base.rb', line 40 def with_level(new_level) old_level = level self.level = new_level yield ensure self.level = old_level end |