Class: SemanticLogger::DebugAsTraceLogger
- Defined in:
- lib/semantic_logger/debug_as_trace_logger.rb
Overview
Custom logger that maps all calls to debug to trace calls This is useful for existing gems / libraries that log too much to debug when most of the debug logging should be at the trace level
Instance Attribute Summary
Attributes inherited from Base
#filter, #instance_named_tags, #instance_tags, #name
Method Summary
Methods inherited from Logger
call_subscribers, #initialize, #log, processor, subscribe, sync!, sync?
Methods included from Concerns::Compatibility
#add, #close, included, #reopen
Methods inherited from Base
#backtrace, #fast_tag, #level, #level=, #log, #measure, #named_tags, #pop_tags, #push_tags, #should_log?, #silence, #tagged, #tags, #with_level
Constructor Details
This class inherits a constructor from SemanticLogger::Logger